@@ -449,8 +449,8 @@ check_payment_cb (void *cls,
   GNUNET_assert (MHD_HTTP_OK == hr->http_status);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Payment status checked: %d\n",
-              osr->details.success.status);
-  switch (osr->details.success.status)
+              osr->details.ok.status);
+  switch (osr->details.ok.status)
   {
   case TALER_MERCHANT_OSC_PAID:
     {
@@ -540,6 +540,7 @@ static MHD_RESULT
 begin_payment (struct BackupContext *bc,
                int pay_req)
 {
+  static const char *no_uuids[1] = { NULL };
   json_t *order;
 
   if (! bc->force_fresh_order)
@@ -597,7 +598,7 @@ begin_payment (struct BackupContext *bc,
                                         0,
                                         NULL, /* no inventory products */
                                         0,
-                                        NULL, /* no uuids */
+                                        no_uuids, /* no uuids */
                                         false, /* do NOT require claim token */
                                         &proposal_cb,
                                         bc);
@@ -769,18 +770,23 @@ SH_backup_post (struct MHD_Connection *connection,
       im = MHD_lookup_connection_value (connection,
                                         MHD_HEADER_KIND,
                                         MHD_HTTP_HEADER_IF_MATCH);
-      if ( (NULL != im) &&
-           (GNUNET_OK !=
-            GNUNET_STRINGS_string_to_data (im,
-                                           strlen (im),
-                                           &bc->old_backup_hash,
-                                           sizeof (bc->old_backup_hash))) )
+      if (NULL != im)
       {
-        GNUNET_break_op (0);
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_BAD_REQUEST,
-                                           TALER_EC_SYNC_BAD_IF_MATCH,
-                                           NULL);
+        if ( (2 >= strlen (im)) ||
+             ('"' != im[0]) ||
+             ('"' != im[strlen (im) - 1]) ||
+             (GNUNET_OK !=
+              GNUNET_STRINGS_string_to_data (im + 1,
+                                             strlen (im) - 2,
+                                             &bc->old_backup_hash,
+                                             sizeof (bc->old_backup_hash))) )
+        {
+          GNUNET_break_op (0);
+          return TALER_MHD_reply_with_error (connection,
+                                             MHD_HTTP_BAD_REQUEST,
+                                             TALER_EC_SYNC_BAD_IF_MATCH,
+                                             NULL);
+        }
       }
     }
     {
@@ -810,9 +816,12 @@ SH_backup_post (struct MHD_Connection *connection,
                                           MHD_HEADER_KIND,
                                           MHD_HTTP_HEADER_IF_NONE_MATCH);
       if ( (NULL == etag) ||
+           (2 >= strlen (etag)) ||
+           ('"' != etag[0]) ||
+           ('"' != etag[strlen (etag) - 1]) ||
            (GNUNET_OK !=
-            GNUNET_STRINGS_string_to_data (etag,
-                                           strlen (etag),
+            GNUNET_STRINGS_string_to_data (etag + 1,
+                                           strlen (etag) - 2,
                                            &bc->new_backup_hash,
                                            sizeof (bc->new_backup_hash))) )
       {
